summaryrefslogtreecommitdiffstats
path: root/src/graphnode.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-10-08 00:13:25 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-10-08 05:14:53 +0200
commit84f5a315c3429b47a7eff15e626e2efdbe4f6e5e (patch)
tree770861aa9033e1dc6c5168358194ff85b32dd429 /src/graphnode.h
parent57d8bb3d12aed373eee08915f0ff19f5233aabe3 (diff)
downloadkscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.tar.gz
kscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.zip
Initial TQt conversion
Diffstat (limited to 'src/graphnode.h')
-rw-r--r--src/graphnode.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/graphnode.h b/src/graphnode.h
index 9f48639..a54b4ea 100644
--- a/src/graphnode.h
+++ b/src/graphnode.h
@@ -28,8 +28,8 @@
#ifndef GRAPHNODE_H
#define GRAPHNODE_H
-#include <qcanvas.h>
-#include <qdict.h>
+#include <ntqcanvas.h>
+#include <ntqdict.h>
#include "graphedge.h"
/**
@@ -37,10 +37,10 @@
* This item represents a function in the call graph.
* @author Elad Lahav
*/
-class GraphNode : public QCanvasPolygon
+class GraphNode : public TQCanvasPolygon
{
public:
- GraphNode(QCanvas* pCanvas, const QString&, bool bMultiCall = false);
+ GraphNode(TQCanvas* pCanvas, const TQString&, bool bMultiCall = false);
~GraphNode();
GraphEdge* addOutEdge(GraphNode*);
@@ -52,17 +52,17 @@ public:
/**
* @param rect The bounding rectangle of the node
*/
- void setRect(const QRect& rect);
+ void setRect(const TQRect& rect);
/**
* @param font The font to use for drawing the text
*/
- void setFont(const QFont& font) { m_font = font; }
+ void setFont(const TQFont& font) { m_font = font; }
/**
* @return The name of the function
*/
- const QString& getFunc() const { return m_sFunc; }
+ const TQString& getFunc() const { return m_sFunc; }
/**
* @return true for a multiple-call node, false otherwise
@@ -72,7 +72,7 @@ public:
/**
* @return The set of outgoing edges
*/
- QDict<GraphEdge>& getOutEdges() { return m_dictOutEdges; }
+ TQDict<GraphEdge>& getOutEdges() { return m_dictOutEdges; }
/**
* @return true if this node was already visited during the current DFS,
@@ -85,7 +85,7 @@ public:
*/
void dfsReset() { m_bDfsFlag = false; }
/** Identifies this class among other QCanvasItem classes. */
static int RTTI;
/**
@@ -94,23 +94,23 @@ public:
virtual int rtti() const { return RTTI; }
protected:
- virtual void drawShape(QPainter&);
+ virtual void drawShape(TQPainter&);
private:
/** Function name. */
- QString m_sFunc;
+ TQString m_sFunc;
/** A list of outgoing edges indexed by destination. */
- QDict<GraphEdge> m_dictOutEdges;
+ TQDict<GraphEdge> m_dictOutEdges;
/** A list of incoming edges indexed by destination. */
- QDict<GraphEdge> m_dictInEdges;
+ TQDict<GraphEdge> m_dictInEdges;
/** The bounding rectangle for the node. */
- QRect m_rect;
+ TQRect m_rect;
/** The font to use for drawing the text. */
- QFont m_font;
+ TQFont m_font;
/** true for a multiple-call node, false otherwise. */
bool m_bMultiCall;
@@ -85,7 +85,7 @@ public:
*/
void dfsReset() { m_bDfsFlag = false; }
- /** Identifies this class among other QCanvasItem classes. */
+ /** Identifies this class among other TQCanvasItem classes. */
static int RTTI;
/**